sievetools.ResidueClass
=======================

.. abjad-lineage:: abjad.tools.sievetools.ResidueClass.ResidueClass

.. autoclass:: abjad.tools.sievetools.ResidueClass.ResidueClass

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.sievetools.ResidueClass.ResidueClass.get_boolean_train
      ~abjad.tools.sievetools.ResidueClass.ResidueClass.get_congruent_bases
      ~abjad.tools.sievetools.ResidueClass.ResidueClass.modulo
      ~abjad.tools.sievetools.ResidueClass.ResidueClass.residue
      ~abjad.tools.sievetools.ResidueClass.ResidueClass.__and__
      ~abjad.tools.sievetools.ResidueClass.ResidueClass.__eq__
      ~abjad.tools.sievetools.ResidueClass.ResidueClass.__format__
      ~abjad.tools.sievetools.ResidueClass.ResidueClass.__ge__
      ~abjad.tools.sievetools.ResidueClass.ResidueClass.__gt__
      ~abjad.tools.sievetools.ResidueClass.ResidueClass.__hash__
      ~abjad.tools.sievetools.ResidueClass.ResidueClass.__le__
      ~abjad.tools.sievetools.ResidueClass.ResidueClass.__lt__
      ~abjad.tools.sievetools.ResidueClass.ResidueClass.__ne__
      ~abjad.tools.sievetools.ResidueClass.ResidueClass.__or__
      ~abjad.tools.sievetools.ResidueClass.ResidueClass.__repr__
      ~abjad.tools.sievetools.ResidueClass.ResidueClass.__xor__

Bases
-----

- :py:class:`sievetools.BaseResidueClass <abjad.tools.sievetools.BaseResidueClass.BaseResidueClass>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.sievetools.ResidueClass.ResidueClass.modulo
   :noindex:

.. autoattribute:: abjad.tools.sievetools.ResidueClass.ResidueClass.residue
   :noindex:

Methods
-------

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.get_boolean_train
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.get_congruent_bases
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.__and__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.__eq__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.__format__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.__ge__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.__gt__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.__hash__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.__le__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.__lt__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.__ne__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.__or__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.__repr__
   :noindex:

.. automethod:: abjad.tools.sievetools.ResidueClass.ResidueClass.__xor__
   :noindex:
